searchData={"items":[{"type":"module","title":"ExCell","doc":"ExCell is used to split larger views in smaller cells that can be reused and\neasily packaged with Javascript and CSS.\n\nA cell consists of a couple of files:\n```\ncells\n|- avatar\n|  |- template.html.eex\n|  |- view.html.eex\n|  |- style.css (optional)\n|  |- index.js (optional)\n|- header\n...\n```\n\nYou can render the cell in a view, controller or another cell by adding the following code:\n```ex\ncell(AvatarCell, class: \"CustomClassName\", user: %User{})\n```\n\nThis would generate the following HTML when you render the cell:\n\n```html\n \n   \n \n```","ref":"ExCell.html"},{"type":"function","title":"ExCell.class_name/2","doc":"","ref":"ExCell.html#class_name/2"},{"type":"function","title":"ExCell.config/2","doc":"","ref":"ExCell.html#config/2"},{"type":"function","title":"ExCell.container/5","doc":"","ref":"ExCell.html#container/5"},{"type":"function","title":"ExCell.module_relative_to/2","doc":"","ref":"ExCell.html#module_relative_to/2"},{"type":"function","title":"ExCell.options/5","doc":"","ref":"ExCell.html#options/5"},{"type":"function","title":"ExCell.relative_name/2","doc":"","ref":"ExCell.html#relative_name/2"},{"type":"behaviour","title":"ExCell.Adapter","doc":"An ExCell Adapter defines the way the adapter outputs its HTML. The adapter\nrequires a function called adapter that accepts a map container name,\nattributes, params and the content. It should return a Phoenix.HTML safe string.","ref":"ExCell.Adapter.html"},{"type":"callback","title":"ExCell.Adapter.container/1","doc":"","ref":"ExCell.Adapter.html#c:container/1"},{"type":"type","title":"ExCell.Adapter.html/0","doc":"","ref":"ExCell.Adapter.html#t:html/0"},{"type":"type","title":"ExCell.Adapter.options/0","doc":"","ref":"ExCell.Adapter.html#t:options/0"},{"type":"module","title":"ExCell.Adapters.CellJS","doc":"The CellJS adapter can be used to output the cells as HTML compatible with\n[cells-js](https://github.com/DefactoSoftware/cells-js). CellsJS was written\nwith ExCell in mind.\n\nTags are automatically closed when they are part of the\n[void elements](https://stackoverflow.com/questions/4693939/self-closing-tags-void-elements-in-html5)\nspecification.\n\nCellsJS uses two predefined attributes to parse the Javascript. First it\nwill look for the `data-cell` cell attribute and match it to the defined Cell\nin Javascript.\n\nSecond it will take the JSON arguments set on the `data-cell-params` attribute\nand use that to initialize the cell with user defined parameters.","ref":"ExCell.Adapters.CellJS.html"},{"type":"function","title":"ExCell.Adapters.CellJS.attributes/4","doc":"The attributes function is used to auto fill the attributes for a container\nwith the data attributes.","ref":"ExCell.Adapters.CellJS.html#attributes/4"},{"type":"function","title":"ExCell.Adapters.CellJS.container/1","doc":"The container renders HTML with the attributes, class name and data attributes\nprefilled. The HTML is rendered with Phoenix.HTML.Tag.","ref":"ExCell.Adapters.CellJS.html#container/1"},{"type":"function","title":"ExCell.Adapters.CellJS.container/2","doc":"","ref":"ExCell.Adapters.CellJS.html#container/2"},{"type":"function","title":"ExCell.Adapters.CellJS.data_attribute/4","doc":"The data_attribute function is used to build up the data attributes and set\nthe default `data-cell` and `data-cell-params` attributes.","ref":"ExCell.Adapters.CellJS.html#data_attribute/4"},{"type":"function","title":"ExCell.Adapters.CellJS.element/2","doc":"","ref":"ExCell.Adapters.CellJS.html#element/2"},{"type":"function","title":"ExCell.Adapters.CellJS.void_element?/1","doc":"","ref":"ExCell.Adapters.CellJS.html#void_element?/1"},{"type":"function","title":"ExCell.Adapters.CellJS.void_elements/0","doc":"","ref":"ExCell.Adapters.CellJS.html#void_elements/0"},{"type":"behaviour","title":"ExCell.Cell","doc":"Cells are used to tightly couple your templates, views and Javascript. It is\nheavily inspired by React by Facebook and Rails Cells by Trailblazer.","ref":"ExCell.Cell.html"},{"type":"function","title":"ExCell.Cell.__adapter__/0","doc":"Returns the name of the module as a string. Module namespaces are replaced\nby a dash.","ref":"ExCell.Cell.html#__adapter__/0"},{"type":"function","title":"Example - ExCell.Cell.__adapter__/0","doc":"iex(0)> AvatarCell.name()\n  \"AvatarCell\"\n\n  iex(1)> User.AvatarCell.name()\n  \"User-AvatarCell\"","ref":"ExCell.Cell.html#__adapter__/0-example"},{"type":"macro","title":"ExCell.Cell.__using__/1","doc":"Cells require you to use the __using__ macro to use them. This ensures that\nthe cell namespaces are used.\n\nThe cell allows you to override the class_name and params attributes.","ref":"ExCell.Cell.html#__using__/1"},{"type":"macro","title":"Options - ExCell.Cell.__using__/1","doc":"When you use the `__using__` macro you can specify a namespace it uses as its\nbase to add the class and cells-js tags\n\n- `:namespace` - The base namespace it uses to base the `name` and `class_name` on","ref":"ExCell.Cell.html#__using__/1-options"},{"type":"macro","title":"Examples - ExCell.Cell.__using__/1","doc":"defmodule AppWeb.AvatarCell do\n      use ExCell.Cell, namespace: AppWeb\n    end\n\n    iex(0)> AvatarCell.name\n    \"AvatarCell\"\n\n    defmodule AppWeb.AvatarCell do\n      use ExCell.Cell\n    end\n\n    iex(0)> AvatarCell.name\n    \"AppWeb-AvatarCell\"","ref":"ExCell.Cell.html#__using__/1-examples"},{"type":"function","title":"ExCell.Cell.cell_name/0","doc":"Generates the HTML attribute name based on the cell name. Can be overriden\nto pre- or postfix the attribute name.","ref":"ExCell.Cell.html#cell_name/0"},{"type":"function","title":"Examples - ExCell.Cell.cell_name/0","doc":"iex(0)> AvatarCell.cell_name()\n    \"AvatarCell\"","ref":"ExCell.Cell.html#cell_name/0-examples"},{"type":"function","title":"ExCell.Cell.class_name/0","doc":"Generates the CSS class name based on the cell name. Can be overriden\nto pre- or postfix the class name or to create a distinct class name with\nCSS modules.","ref":"ExCell.Cell.html#class_name/0"},{"type":"function","title":"Examples - ExCell.Cell.class_name/0","doc":"iex(0)> AvatarCell.class_name()\n    \"AvatarCell\"","ref":"ExCell.Cell.html#class_name/0-examples"},{"type":"callback","title":"ExCell.Cell.class_name/0","doc":"","ref":"ExCell.Cell.html#c:class_name/0"},{"type":"function","title":"ExCell.Cell.container/0","doc":"Returns the container of a cell as a Phoenix.Tag.\n\n    iex(0)> Phoenix.HTML.safe_to_string(AvatarCell.container)\n    \" \"","ref":"ExCell.Cell.html#container/0"},{"type":"function","title":"ExCell.Cell.container/1","doc":"Returns the container of a cell as a Phoenix.Tag with attributes added to\nthe data-cell-params attribute. This is used to add parameters to `cell-js` cells.","ref":"ExCell.Cell.html#container/1"},{"type":"function","title":"Examples - ExCell.Cell.container/1","doc":"iex(0)> Phoenix.HTML.safe_to_string(AvatarCell.container(%{ foo: \"bar\" }))\n    \" \"","ref":"ExCell.Cell.html#container/1-examples"},{"type":"function","title":"ExCell.Cell.container/2","doc":"","ref":"ExCell.Cell.html#container/2"},{"type":"function","title":"ExCell.Cell.container/3","doc":"","ref":"ExCell.Cell.html#container/3"},{"type":"function","title":"ExCell.Cell.name/0","doc":"","ref":"ExCell.Cell.html#name/0"},{"type":"callback","title":"ExCell.Cell.params/0","doc":"","ref":"ExCell.Cell.html#c:params/0"},{"type":"function","title":"ExCell.Cell.params/1","doc":"Combines the parameters set on the cell with custom parameters for a\nspecific instance","ref":"ExCell.Cell.html#params/1"},{"type":"function","title":"Examples - ExCell.Cell.params/1","doc":"iex(0)> AvatarCell.params\n    %{hello: \"world\"}\n    iex(0)> AvatarCell.params(%{foo: \"bar\"})\n    %{hello: \"world\", foo: \"bar\"}","ref":"ExCell.Cell.html#params/1-examples"},{"type":"module","title":"ExCell.Controller","doc":"Cell methods that render a cell directly to a controller","ref":"ExCell.Controller.html"},{"type":"function","title":"ExCell.Controller.cell/1","doc":"Renders a cell directly from a controller without having to use a view.","ref":"ExCell.Controller.html#cell/1"},{"type":"function","title":"Examples - ExCell.Controller.cell/1","doc":"defmodule AppWeb.UserController do\n      use AppWeb, :controller\n      import Cell.Controller\n\n      def avatar(conn, _params) do\n        conn\n        |> cell(AvatarCell, user: conn.user)\n      end\n    end","ref":"ExCell.Controller.html#cell/1-examples"},{"type":"function","title":"ExCell.Controller.cell/2","doc":"","ref":"ExCell.Controller.html#cell/2"},{"type":"function","title":"ExCell.Controller.cell/3","doc":"","ref":"ExCell.Controller.html#cell/3"},{"type":"module","title":"ExCell.View","doc":"Cell helpers used to render the cells in both Views and Cells","ref":"ExCell.View.html"},{"type":"function","title":"ExCell.View.cell/1","doc":"Renders a cell in the view.","ref":"ExCell.View.html#cell/1"},{"type":"function","title":"Examples - ExCell.View.cell/1","doc":"iex(0)> safe_to_string(AppWeb.AvatarView.cell(AvatarCell))\n    \" \"\n\n    iex(1)> safe_to_string(AppWeb.AvatarView.cell(AvatarCell, do: \"Foo\"))\n    \" Foo \"\n\n    iex(2)> safe_to_string(AppWeb.AvatarView.cell(AvatarCell, user: %User{name: \"Bar\"}))\n    \" Bar \"\n\n    iex(3)> safe_to_string(AppWeb.AvatarView.cell(AvatarCell, %Plug.Conn{} |> assign(:user, %User{name: \"Bar\"})))\n    \" Bar \"\n\n    iex(4)> safe_to_string(AppWeb.AvatarView.cell(AvatarCell, \"Hello\"))\n    \" Hello \"","ref":"ExCell.View.html#cell/1-examples"},{"type":"function","title":"ExCell.View.cell/2","doc":"","ref":"ExCell.View.html#cell/2"},{"type":"function","title":"ExCell.View.cell/3","doc":"","ref":"ExCell.View.html#cell/3"},{"type":"function","title":"ExCell.View.cell_to_string/1","doc":"Renders the cell directly as a string, used for testing purposes.","ref":"ExCell.View.html#cell_to_string/1"},{"type":"function","title":"Examples - ExCell.View.cell_to_string/1","doc":"iex(0)> AppWeb.AvatarView.cell_to_string(AvatarCell)\n    \" \"\n\n    iex(1)> AppWeb.AvatarView.cell_to_string(AvatarCell, do: \"Foo\")\n    \" Foo \"\n\n    iex(2)> AppWeb.AvatarView.cell_to_string(AvatarCell, user: %User{name: \"Bar\"})\n    \" Bar \"","ref":"ExCell.View.html#cell_to_string/1-examples"},{"type":"function","title":"ExCell.View.cell_to_string/2","doc":"","ref":"ExCell.View.html#cell_to_string/2"},{"type":"function","title":"ExCell.View.cell_to_string/3","doc":"","ref":"ExCell.View.html#cell_to_string/3"},{"type":"function","title":"ExCell.View.relative_path/2","doc":"Returns the relative path of a module to the namespace. This method is used\nto determine the template path of the cell.","ref":"ExCell.View.html#relative_path/2"},{"type":"function","title":"Examples - ExCell.View.relative_path/2","doc":"iex(0)> ExCell.View.relative_path(AppWeb.AvatarCell, AppWeb)\n    \"avatar\"\n\n    iex(1)> ExCell.View.relative_path(AppWeb.Namespace.AvatarCell, AppWeb)\n    \"namespace/avatar\"","ref":"ExCell.View.html#relative_path/2-examples"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}